@@ -22,7 +22,7 @@ if six.PY3:
 else:
     import re
 
-    _find_unsafe = re.compile(r'[^\w@%+=:,./-]').search
+    _find_unsafe = re.compile(r"[^\w@%+=:,./-]").search
 
     def quote(s):
         """Return a shell-escaped version of the string *s*."""
