@@ -1,6 +1,6 @@
 """Module version information."""
 
-# Copyright 2016-2017 ASI Data Science
+# Copyright 2016-2018 ASI Data Science
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,10 +16,11 @@
 
 import platform
 
-__version__ = '0.7.3'
+__version__ = "0.10.2"
 
 
 def user_agent():
     """Return user agent string."""
-    return 'sml/{} (Python {}, {})'.format(
-        __version__, platform.python_version(), platform.platform())
+    return "sml/{} (Python {}, {})".format(
+        __version__, platform.python_version(), platform.platform()
+    )
